<?php
/**
 * Bozu Dynamic Styles
 *
 * @package Bozu
 */

function bozu_dynamic_css()
{

    $bozu_default = bozu_get_default_theme_options();
    $background_color = get_theme_mod('background_color', $bozu_default['background_color']);

    $background_color = '#' . str_replace("#", "", $background_color);

    $bozu_header_text_color = get_theme_mod('bozu_header_text_color', $bozu_default['bozu_header_text_color']);

    $bozu_slider_text_color = get_theme_mod('bozu_slider_text_color', $bozu_default['bozu_slider_text_color']);
    
    $bozu_testimonial_bg_color = get_theme_mod('bozu_testimonial_bg_color', $bozu_default['bozu_testimonial_bg_color']);
    $logo_width_range = get_theme_mod('logo_width_range', $bozu_default['logo_width_range']);

    $homepage_cta_text_color = get_theme_mod('homepage_cta_text_color', $bozu_default['homepage_cta_text_color']);
    $category_title_text_color = get_theme_mod('category_title_text_color', $bozu_default['category_title_text_color']);

    $bozu_primary_color = get_theme_mod('bozu_primary_color', $bozu_default['bozu_primary_color']);
    $bozu_secondary_color = get_theme_mod('bozu_secondary_color', $bozu_default['bozu_secondary_color']);
    $bozu_general_color = get_theme_mod('bozu_general_color', $bozu_default['bozu_general_color']);


    $bozu_category_colors = get_theme_mod('bozu_category_colors', $bozu_default['bozu_category_colors']);

    echo "<style type='text/css' media='all'>"; ?>

    <?php
    if ($bozu_category_colors) {
        $bozu_category_colors = json_decode($bozu_category_colors);
        foreach ($bozu_category_colors as $bozu_category_color) {
            if (isset($bozu_category_color->category) && $bozu_category_color->category && isset($bozu_category_color->category_color) && $bozu_category_color->category_color) { ?>

                .bozu-cat-color-<?php echo esc_attr($bozu_category_color->category); ?>{
                background-color: <?php echo esc_attr($bozu_category_color->category_color); ?> !important;
                }

                <?php
            }
        }
    } ?>

    .site-logo .custom-logo{
    max-width:  <?php echo esc_attr($logo_width_range); ?>px;
    }

    body.theme-color-schema,
    .preloader,
    .floating-post-navigation .floating-navigation-label,
    .header-searchbar-inner,
    .offcanvas-wraper{
    background-color: <?php echo esc_attr($background_color); ?>;
    }
    body.theme-color-schema,
    body, input, select, optgroup, textarea,
    .floating-post-navigation .floating-navigation-label,
    .header-searchbar-inner,
    .offcanvas-wraper{
    color: <?php echo esc_attr($bozu_general_color); ?>;
    }

    .preloader .loader-circles span{
    background: <?php echo esc_attr($bozu_general_color); ?>;
    }

    .theme-main-banner{
    color: <?php echo esc_attr($bozu_header_text_color); ?>;
    }

    .theme-block-sliders,
    .theme-block-sliders .theme-block-title a:not(:hover):not(:focus){
    color: <?php echo esc_attr($bozu_slider_text_color); ?>;
    }

    .categories-panel .theme-block-title{
    color: <?php echo esc_attr($category_title_text_color); ?>;
    }

    .theme-block-cta .cta-panel{
    color: <?php echo esc_attr($homepage_cta_text_color); ?>;
    }

    a{
    color: <?php echo esc_attr($bozu_primary_color); ?>;
    }

    body .entry-thumbnail .trend-item,
    body .category-widget-header .post-count,
    body .entry-meta-categories a:hover,
    body .entry-meta-categories a:focus{
    background: <?php echo esc_attr($bozu_secondary_color); ?>;
    }

    body a:hover,
    body a:focus,
    body .footer-credits a:hover,
    body .footer-credits a:focus,
    body .widget a:hover,
    body .widget a:focus {
    color: <?php echo esc_attr($bozu_secondary_color); ?>;
    }
    body input[type="text"]:hover,
    body input[type="text"]:focus,
    body input[type="password"]:hover,
    body input[type="password"]:focus,
    body input[type="email"]:hover,
    body input[type="email"]:focus,
    body input[type="url"]:hover,
    body input[type="url"]:focus,
    body input[type="date"]:hover,
    body input[type="date"]:focus,
    body input[type="month"]:hover,
    body input[type="month"]:focus,
    body input[type="time"]:hover,
    body input[type="time"]:focus,
    body input[type="datetime"]:hover,
    body input[type="datetime"]:focus,
    body input[type="datetime-local"]:hover,
    body input[type="datetime-local"]:focus,
    body input[type="week"]:hover,
    body input[type="week"]:focus,
    body input[type="number"]:hover,
    body input[type="number"]:focus,
    body input[type="search"]:hover,
    body input[type="search"]:focus,
    body input[type="tel"]:hover,
    body input[type="tel"]:focus,
    body input[type="color"]:hover,
    body input[type="color"]:focus,
    body textarea:hover,
    body textarea:focus,
    button:focus,
    body .button:focus,
    body .wp-block-button__link:focus,
    body .wp-block-file__button:focus,
    body input[type="button"]:focus,
    body input[type="reset"]:focus,
    body input[type="submit"]:focus,
    body .entry-meta-categories a:hover,
    body .entry-meta-categories a:focus{
    border-color:  <?php echo esc_attr($bozu_secondary_color); ?>;
    }
    body .theme-page-vitals:after {
    border-right-color:  <?php echo esc_attr($bozu_secondary_color); ?>;
    }
    body a:focus,
    body .theme-action-control:focus > .action-control-trigger,
    body .submenu-toggle:focus > .btn__content{
    outline-color:  <?php echo esc_attr($bozu_secondary_color); ?>;
    }

    .theme-block-testimonials{
        background-color: <?php echo esc_attr($bozu_testimonial_bg_color); ?>;
    }
    <?php echo "</style>";
}

add_action('wp_head', 'bozu_dynamic_css', 100);

/**
 * Sanitizing Hex color function.
 */
function bozu_sanitize_hex_color($color)
{

    if ('' === $color)
        return '';
    if (preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $color))
        return $color;

}