<?php
/**
 * Header file for the Bozu WordPress theme.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Bozu
 * @since 1.0.0
 */
?><!DOCTYPE html>
<html class="no-js" <?php language_attributes(); ?>>

<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <link rel="profile" href="https://gmpg.org/xfn/11">
    <?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php
if (function_exists('wp_body_open')) {
    wp_body_open();
} ?>


<div class="preloader hide-no-js">
    <div class="preloader-wrapper">
        <div class="loader-circles">
            <span></span><span></span><span></span><span></span><span></span>
        </div>
    </div>
</div>

<div id="page" class="site">
    <a class="skip-link screen-reader-text"
       href="#site-contentarea"><?php esc_html_e('Skip to the content', 'bozu'); ?></a>


    <?php get_template_part('template-parts/header/header', 'content'); ?>

    <?php if (is_front_page()) { ?>
        <!-- banner/header image section -->
        <?php bozu_header_image_section(); ?>
    <?php } ?>
    <div id="content" class="site-content">
        <?php
        $bozu_default = bozu_get_default_theme_options();
        $bozu_ed_feature_image = get_post_meta(get_the_ID(), 'bozu_ed_feature_image', true);
        $bozu_single_post_layout = get_theme_mod('bozu_single_post_layout', $bozu_default['bozu_single_post_layout']);
        if( is_page() ) {
            $bozu_single_post_layout = get_post_meta(get_the_ID(), 'bozu_page_layout', true);
        } else {
        $bozu_single_post_layout = get_post_meta(get_the_ID(), 'bozu_post_layout', true);
            
        }

        if (!is_front_page() && ($bozu_single_post_layout != 'layout-2') && (!is_page())) { ?>

            <div class="wrapper">
                <div class="theme-block-header">
                    <?php bozu_archive_title();
                    bozu_breadcrumb();
                    ?>
                </div>
            </div>
        <?php } ?>

        <?php
        if (is_single() || is_page()) {

        ?>
        <?php if ($bozu_single_post_layout == 'layout-2') { ?>
        <div class="single-featured-banner">
            <?php

            $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
            $featured_image = isset($featured_image[0]) ? $featured_image[0] : '';
            ?>
            <div class="data-bg" <?php if (empty( $bozu_ed_feature_image )) { ?> data-background="<?php echo esc_url($featured_image); ?>" <?php } ?>>
                <div class="wrapper">
                    <div class="column-row">
                        <div class="column column-11">
                            <div class="featured-banner-content">
                                <?php if (!is_page()) {  
                                    bozu_breadcrumb(); ?>
                                    <div class="entry-meta">
                                        <?php bozu_entry_footer($cats = true, $tags = false, $edits = false); ?>
                                    </div>
                                <?php } ?>
                                <header class="entry-header">
                                    <h1 class="entry-title entry-title-large">
                                        <?php the_title(); ?>
                                    </h1>
                                </header>
                                <?php if (!is_page()) {  ?>
                                    <div class="entry-meta">
                                        <?php global $post;
                                        $author_id = $post->post_author;?>
                                        <div class="entry-meta-item entry-meta-author">
                                            <?php bozu_the_theme_svg('user'); ?>
                                            <?php $byline = '<span class="author vcard"><a class="url fn n" href="' . esc_url(get_author_posts_url(get_the_author_meta('ID'))) . '">' . esc_html(get_the_author_meta('display_name', $author_id)) . '</a></span>'; ?>
                                            <?php echo wp_kses_post($byline); ?>
                                        </div>
                                        <?php
                                        bozu_posted_on();
                                        ?>
                                    </div>
                                <?php } ?>
                            </div>
                        </div>
                    </div>

                    <?php if ('post' === get_post_type() && class_exists('Booster_Extension_Class') && (empty($bozu_ed_post_views) || empty($bozu_ed_post_read_time))) { ?>
                        <div class="column-row">
                            <div class="column column-12">
                                <div class="theme-page-vitals">

                                    <?php
                                    if (empty($bozu_ed_post_read_time)) {
                                        echo do_shortcode('[booster-extension-read-time]');
                                    } ?>

                                    <?php
                                    if (empty($bozu_ed_post_views)) {
                                        echo do_shortcode('[booster-extension-visit-count container="true"]');
                                    } ?>

                                </div>
                            </div>
                        </div>

                    <?php } ?>
                </div>
            </div>



        </div>
<?php }
}