<?php
/**
 * Custom Functions.
 *
 * @package Bozu
 */

if( !function_exists( 'bozu_header_image_section' ) ) :

    function bozu_header_image_section(){
        $bozu_default = bozu_get_default_theme_options();
        $ed_header_banner = get_theme_mod( 'ed_header_banner', $bozu_default['ed_header_banner'] );

        if ($ed_header_banner) {
            $header_banner_title = get_theme_mod( 'header_banner_title',$bozu_default['header_banner_title'] );
            $header_banner_sub_title = get_theme_mod( 'header_banner_sub_title',$bozu_default['header_banner_sub_title'] );
            $header_banner_description = get_theme_mod( 'header_banner_description',$bozu_default['header_banner_description'] );
            $header_banner_button_label = get_theme_mod( 'header_banner_button_label',$bozu_default['header_banner_button_label'] );
            $header_banner_button_link = get_theme_mod( 'header_banner_button_link',$bozu_default['header_banner_button_link'] );
            $ed_open_link_new_tab = get_theme_mod( 'ed_open_link_new_tab',$bozu_default['ed_open_link_new_tab'] );
            $ed_header_banner_overlay = get_theme_mod( 'ed_header_banner_overlay',$bozu_default['ed_header_banner_overlay'] );
            $header_image_url = get_header_image()
            ?>
            
            <div class="theme-block theme-block-banner theme-block-large-space <?php if($header_image_url){ echo 'data-bg'; }?>" data-background="<?php echo esc_url($header_image_url); ?>">
                <?php if ($ed_header_banner_overlay) { ?>
                    <div class="data-bg-overlay"></div>
                <?php } ?>
                <div class="wrapper">
                    <div class="theme-main-banner">
                        <div class="column-row">
                            <div class="column column-12 column-sm-12">
                                <div class="main-banner-details">
                                    <h2 class="theme-block-title-xlarge main-banner-title"><?php echo esc_html($header_banner_title); ?></h2>
                                    <h3 class="main-banner-subtitle"><?php echo esc_html($header_banner_sub_title); ?></h3>
                                    <div class="main-banner-description">
                                        <?php echo wp_kses_post($header_banner_description); ?>
                                    </div>

                                    <?php
                                    if ($header_banner_button_label) { ?>
                                        <div class="theme-block-link">
                                            <a href="<?php echo esc_url($header_banner_button_link); ?>" class="theme-button theme-button-large" <?php if($ed_open_link_new_tab){ ?>target="_blank"<?php } ?>>
                                                <span><?php echo esc_html($header_banner_button_label); ?></span>
                                                <span><?php bozu_the_theme_svg('arrow-right'); ?></span>
                                            </a>
                                        </div>
                                    <?php } ?>

                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
        }
    }

endif;

if( !function_exists( 'bozu_category_section' ) ) :

    function bozu_category_section(){
        $bozu_default = bozu_get_default_theme_options();
        $ed_category_section = get_theme_mod( 'ed_category_section', $bozu_default['ed_category_section'] );
        $ed_category_description = get_theme_mod( 'ed_category_description', $bozu_default['ed_category_description'] );
        if ($ed_category_section) { ?>
            <div class="theme-block theme-block-categories">
                <div class="wrapper">
                    <div class="theme-categories-panels">
                        <div class="column-row">
                            <?php for ($i=1; $i <= 3; $i++) { 
                                $bozu_get_cat_id = absint(get_theme_mod('select_category_for_cat_list_'.$i));
                                $twp_term_image = get_term_meta( $bozu_get_cat_id, 'twp-term-featured-image', true );
                                $twp_cat_link = get_category_link($bozu_get_cat_id);
                                $twp_cat_description = category_description($bozu_get_cat_id);
                                ?>
                                    <div class="column column-4 column-sm-12">
                                        <div class="categories-panel">

                                            <div class="categories-panel-header">
                                                <div class="category-panel-image <?php if ($twp_term_image){ echo 'data-bg data-bg-small';} ?>" data-background="<?php echo esc_url($twp_term_image); ?>">
                                                    <?php if ( get_theme_mod('ed_category_image_overlay') == 1) { ?>
                                                        <div class="data-bg-overlay"></div>
                                                    <?php } ?>
                                                    
                                                </div>
                                            </div>

                                            <div class="categories-panel-content">
                                                <h2 class="theme-block-title">
                                                    <a href="<?php echo esc_url($twp_cat_link); ?>">
                                                        <?php echo esc_html(get_cat_name( $bozu_get_cat_id));?>
                                                    </a>
                                                </h2>
                                                <?php if (($ed_category_description == 1) && !empty($twp_cat_description)) { ?>
                                                    <div class="categories-panel-description">
                                                        <?php echo wp_kses_post($twp_cat_description); ?>
                                                    </div>
                                                    <div class="theme-block-link">
                                                        <a href="<?php echo esc_url($twp_cat_link); ?>">
                                                            <?php esc_html_e('Learn More', 'bozu'); ?>
                                                        </a>
                                                    </div>
                                                <?php } ?>
                                               

                                            </div>
                                        </div>
                                    </div>
                            <?php  } ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php }
    }

endif;


if( !function_exists( 'bozu_cta_section' ) ) :

    function bozu_cta_section(){
        $bozu_default = bozu_get_default_theme_options();
        $ed_cta_section = get_theme_mod( 'ed_cta_section', $bozu_default['ed_cta_section'] );
        $ed_cta_post_excerpt = get_theme_mod( 'ed_cta_post_excerpt', $bozu_default['ed_cta_post_excerpt'] );
        if ($ed_cta_section) {
        $bozu_cta_page = esc_attr(get_theme_mod('select_page_for_cta'));
        if (!empty($bozu_cta_page)) {
            $bozu_cta_page_args = array(
                'post_type' => 'page',
                'page_id' => $bozu_cta_page,
            );
        }
        $homepage_cta_button_text = get_theme_mod( 'homepage_cta_button_text',$bozu_default['homepage_cta_button_text'] );
        $header_banner_button_link = get_theme_mod( 'header_banner_button_link',$bozu_default['header_banner_button_link'] );
        $cta_link_tab = get_theme_mod( 'cta_link_tab',$bozu_default['cta_link_tab'] );
        $ed_cta_image_overlay = get_theme_mod( 'ed_cta_image_overlay',$bozu_default['ed_cta_image_overlay'] );
        if (!empty($bozu_cta_page_args)) {
            $bozu_cta_page_query = new WP_Query($bozu_cta_page_args);
            while ($bozu_cta_page_query->have_posts()): $bozu_cta_page_query->the_post();
                $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
                $featured_image = isset($featured_image[0]) ? $featured_image[0] : '';
                ?>
                <div class="theme-block theme-block-cta">
                    <div class="wrapper">
                        <div class="theme-cta-panel <?php if ($featured_image){ echo 'data-bg';} ?>" data-background="<?php echo esc_url($featured_image); ?>">
                        <?php if($ed_cta_image_overlay){ ?>
                                <div class="data-bg-overlay"></div>
                            <?php } ?>
                            <div class="column-row flex-align-center">
                                <div class="column column-8 column-sm-12">
                                    <div class="cta-panel">
                                         <div class="cta-panel-header">
                                             <h2 class="theme-block-title theme-block-title-large">
                                                 <?php the_title();?>
                                             </h2>
                                         </div>
                                         <?php if ($ed_cta_post_excerpt) { ?>
                                            <div class="cta-panel-content">
                                                <?php the_excerpt(); ?>
                                            </div>
                                         <?php } ?>
                                    </div>
                                </div>
                                 <div class="column column-4 column-sm-12">

                                    <?php
                                    if ($homepage_cta_button_text) { ?>
                                        <div class="theme-block-link">
                                            <a href="<?php echo esc_url($header_banner_button_link); ?>" class="theme-button" <?php if($cta_link_tab){ ?>target="_blank"<?php } ?>>
                                                <span><?php echo esc_html($homepage_cta_button_text); ?></span>
                                                <span><?php bozu_the_theme_svg('arrow-right'); ?></span>
                                            </a>
                                        </div>
                                    <?php } ?>
                                 </div>
                            </div>
                        </div>
                    </div>

                </div>
            <?php endwhile;
            wp_reset_postdata();
        }
        }
    }

endif;


if( !function_exists( 'bozu_testimonial_section' ) ) :

    function bozu_testimonial_section(){
        $bozu_default = bozu_get_default_theme_options();
        $ed_testimonial_section = get_theme_mod( 'ed_testimonial_section', $bozu_default['ed_testimonial_section'] );
        $testimonial_bg_image = get_theme_mod( 'testimonial_bg_image');
        if ($ed_testimonial_section) {
        $number_of_testimonial = get_theme_mod( 'number_of_testimonial', $bozu_default['number_of_testimonial'] );

            $bozu_testimonial_page = array();
            for ($i = 1; $i <= $number_of_testimonial; $i++) {
                $bozu_testimonial_page_list = get_theme_mod('select_page_for_testimonial_' . $i);
                if (!empty($bozu_testimonial_page_list)) {
                    $bozu_testimonial_page[] = $bozu_testimonial_page_list;
                }
            }

            // Bail if no valid pages are selected.
            if (empty($bozu_testimonial_page)) {
                return;
            }
            /*page query*/
            $bozu_testimonial_args = array(
                'posts_per_page' => esc_attr($number_of_testimonial),
                'orderby' => 'post__in',
                'post_type' => 'page',
                'post__in' => $bozu_testimonial_page,
            );
                $bozu_testimonial_query = new WP_Query($bozu_testimonial_args); ?>
                <div class="theme-block theme-block-testimonials <?php if ($testimonial_bg_image){echo 'data-bg';} ?>" <?php if ($testimonial_bg_image){ ?>data-background="<?php echo esc_url($testimonial_bg_image); ?>"<?php } ?>>
                    <div class="wrapper wrapper-small">
                        <h2 class="theme-block-title theme-block-title-large text-center">
                            <?php echo wp_kses_post(get_theme_mod('testimonial_section_title')); ?>
                        </h2>
                        <div class="testimonial-slider">
                            <?php
                            if ($bozu_testimonial_query->have_posts()) :
                                while ($bozu_testimonial_query->have_posts()) : $bozu_testimonial_query->the_post();
                                    ?>
                                    <div class="testimonial-slides">
                                        <?php if (has_post_thumbnail()) : ?>
                                            <div class="testimonial-image">
                                                <?php
                                                the_post_thumbnail('medium', [
                                                    'alt' => get_the_title(),
                                                    'class' => 'testimonial-image',
                                                ]);
                                                ?>
                                            </div>
                                        <?php endif; ?>
                                        <div class="testimonial-content text-center">
                                            <h3 class="testimonial-title ">
                                                <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                            </h3>
                                            <div class="testimonial-caption">
                                                <?php if (has_excerpt()) {
                                                    the_excerpt();
                                                    bozu_read_more_page_render();
                                                } else {
                                                    the_excerpt();
                                                } ?>
                                            </div>

                                        </div>
                                    </div>
                                    <?php
                                endwhile;
                                wp_reset_postdata();
                            endif; ?>
                        </div>
                    </div>
                </div>
        <?php }
    }

endif;


if( !function_exists( 'bozu_slider_section' ) ) :

    function bozu_slider_section(){
        $bozu_default = bozu_get_default_theme_options();
        $ed_slider_section = get_theme_mod( 'ed_slider_section', $bozu_default['ed_slider_section'] );
        $ed_slider_control_dot = get_theme_mod( 'ed_slider_control_dot', $bozu_default['ed_slider_control_dot'] );
        $ed_slider_post_excerpt = get_theme_mod( 'ed_slider_post_excerpt', $bozu_default['ed_slider_post_excerpt'] );
        
        if ($ed_slider_section) {
            $number_of_slider = get_theme_mod( 'number_of_slider', $bozu_default['number_of_slider'] );
            $ed_slider_overlay = get_theme_mod( 'ed_slider_overlay', $bozu_default['ed_slider_overlay'] );

                    $bozu_slider_page = array();
                    for ($i = 1; $i <= $number_of_slider; $i++) {
                        $bozu_slider_page_list = get_theme_mod('select_page_for_slider_' . $i);
                        if (!empty($bozu_slider_page_list)) {
                            $bozu_slider_page[] = absint($bozu_slider_page_list);
                        }
                    }
                    // Bail if no valid pages are selected.
                    if (empty($bozu_slider_page)) {
                        return;
                    }
                    /*page query*/
                    $bozu_slider_args = array(
                        'posts_per_page' => esc_attr($number_of_slider),
                        'orderby' => 'post__in',
                        'post_type' => 'page',
                        'post__in' => $bozu_slider_page,
                    );
                $bozu_slider_query = new WP_Query($bozu_slider_args); 
                $data_slick_dot = 'false';
                if ($ed_slider_control_dot) {
                    $data_slick_dot = 'true';
                }
                ?>
                <div class="theme-block theme-block-sliders theme-block-nospace">
                    <div class="main-slider" data-slick='{"dots": <?php echo ($data_slick_dot); ?>}'>
                        <?php
                        if ($bozu_slider_query->have_posts()) :
                            while ($bozu_slider_query->have_posts()) : $bozu_slider_query->the_post();
                                ?>

                                <div class="main-slides-item">
                                    <?php if (has_post_thumbnail()) {
                                        $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full');
                                        $featured_image = isset($featured_image[0]) ? $featured_image[0] : ''; ?>
                                        <div class="theme-slider-image">
                                            <a href="<?php the_permalink(); ?>">
                                                <span class="data-bg data-bg-xlarge" data-background="<?php echo esc_url($featured_image); ?>">
                                                    <?php if ($ed_slider_overlay) { ?>
                                                        <span class="data-bg-overlay"></span>
                                                    <?php } ?>
                                                </span>
                                            </a>
                                        </div>
                                    <?php } ?>

                                    <div class="theme-slider-content text-center">
                                        <div class="wrapper wrapper-small">
                                            <div class="theme-block-heading">
                                                <h3 class="theme-block-title theme-block-title-xlarge">
                                                    <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                                </h3>
                                            </div>
                                            <?php if ($ed_slider_post_excerpt) { ?>
                                                <div class="post-content">
                                                    <?php if (has_excerpt()) {
                                                        the_excerpt();
                                                        bozu_read_more_page_render();
                                                    } else {
                                                        the_excerpt();
                                                    } ?>
                                                </div>
                                            <?php } ?>
                                        </div>
                                    </div>
                                </div>

                                <?php
                            endwhile;
                            wp_reset_postdata();
                        endif; ?>
                    </div>
                </div>
        <?php }
    }

endif;


if( !function_exists( 'bozu_about_section' ) ) :

    function bozu_about_section(){
        $bozu_default = bozu_get_default_theme_options();
        $ed_about_section = get_theme_mod( 'ed_about_section', $bozu_default['ed_about_section'] );
        $homepage_about_title = get_theme_mod( 'about_section_title',$bozu_default['about_section_title'] );
        if ($ed_about_section) {
        $bozu_about_page = esc_attr(get_theme_mod('select_page_for_about'));
        if (!empty($bozu_about_page)) {
            $bozu_about_page_args = array(
                'post_type' => 'page',
                'page_id' => $bozu_about_page,
            );
        }
        if (!empty($bozu_about_page_args)) {
            $bozu_about_page_query = new WP_Query($bozu_about_page_args);
            while ($bozu_about_page_query->have_posts()): $bozu_about_page_query->the_post();
                if (has_post_thumbnail()) { 
                    $thumb = wp_get_attachment_image_src(get_post_thumbnail_id(get_the_ID()), 'full');
                    $url = $thumb['0'];
                }
                ?>

                <div class="theme-block theme-block-space-top theme-block-bg-1 theme-block-about">
                    <div class="wrapper-fluid">
                        <div class="column-row column-row-center">
                            <div class="column column-2 column-sm-12">
                                <div class="theme-section-heading">
                                    <h2 class="theme-section-title alt-font">
                                        <?php echo esc_html($homepage_about_title); ?>
                                    </h2>
                                </div>
                            </div>
                            <div class="column column-3 column-sm-12">
                                <div class="theme-block-heading">
                                        <h3 class="theme-block-title theme-block-title-big">
                                            <a href="<?php the_permalink();?>">
                                                <?php the_title(); ?>
                                            </a>
                                        </h3>
                                </div>

                            </div>


                            <?php if (has_post_thumbnail()) {
                                $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                                $featured_image = isset($featured_image[0]) ? $featured_image[0] : ''; ?>
                                <div class="column column-4 column-sm-12">
                                    <div class="entry-thumbnail mb-sm-20">
                                        <a href="<?php the_permalink(); ?>">
                                            <span class="data-bg data-bg-large" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                        </a>
                                    </div>
                                </div>
                            <?php } ?>
                            <div class="column column-3 column-sm-12 mb-sm-20">
                                <div class="post-content mb-sm-20">
                                    <?php if (has_excerpt()) {
                                        the_excerpt();
                                        bozu_read_more_page_render();
                                    } else {
                                        the_excerpt();
                                    } ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

            <?php endwhile;
            wp_reset_postdata();
        }
        }
    }

endif;


if( !function_exists( 'bozu_services_section' ) ) :

    function bozu_services_section(){
        $bozu_default = bozu_get_default_theme_options();
        $ed_services_section = get_theme_mod( 'ed_services_section', $bozu_default['ed_services_section'] );
        $services_section_title = get_theme_mod( 'services_section_title', $bozu_default['services_section_title'] );
        $services_bg_image = get_theme_mod( 'services_bg_image');
        if ($ed_services_section) {

                    $bozu_services_page = esc_attr(get_theme_mod('select_page_for_services_1'));

                    $bozu_services_pages = array();
                    for ($i = 2; $i <= 3; $i++) {
                        $bozu_services_pages_list = get_theme_mod('select_page_for_services_' . $i);
                        if (!empty($bozu_services_pages_list)) {
                            $bozu_services_pages[] = absint($bozu_services_pages_list);
                        }
                    }
                    // Bail if no valid pages are selected.
                    if (empty($bozu_services_page)) {
                        return;
                    }
                    /*page query*/
                    $bozu_services_args = array(
                        'posts_per_page' => 1,
                        'post_type' => 'page',
                        'page_id' => $bozu_services_page,
                    );
                $bozu_services_query = new WP_Query($bozu_services_args); ?>

                <div class="theme-block theme-block-nospace theme-block-bg theme-block-services">
                    <?php if ($services_bg_image){ ?>
                        <div class="theme-block-services-upper">
                            <div class="wrapper-fluid-collapse">
                                <div class="column-row column-row-collapse">
                                    <div class="column column-6 column-sm-12">
                                    </div>
                                    <div class="column column-6 column-sm-12">
                                            <div class="data-bg data-bg-large" data-background="<?php echo esc_url($services_bg_image); ?>"></div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php } ?>
                    <div class="theme-block-services-group">
                         <div class="wrapper">
                                <div class="column-row">
                                    <div class="column column-1 column-sm-12">
                                        <div class="theme-section-heading">
                                            <h2 class="theme-section-title alt-font mt-sm-20">
                                                <?php echo wp_kses_post($services_section_title); ?>
                                            </h2>
                                        </div>
                                    </div>

                                     <div class="column column-11 column-sm-12">
                                         <div class="theme-block-services-middle">
                                             <div class="column-row">
                                                 <?php
                                                 if ($bozu_services_query->have_posts()) :
                                                     while ($bozu_services_query->have_posts()) : $bozu_services_query->the_post();
                                                         ?>
                                                         <div class="column column-3 column-sm-12">
                                                             <div class="theme-block-heading">
                                                                 <h3 class="theme-block-title theme-block-title-big">
                                                                     <a href="<?php the_permalink(); ?>">
                                                                        <?php the_title(); ?>
                                                                     </a>
                                                                 </h3>
                                                             </div>

                                                             <div class="post-content post-content-small">
                                                                <?php if (has_excerpt()) {
                                                                    the_excerpt();
                                                                    bozu_read_more_page_render();
                                                                } else {
                                                                    the_excerpt();
                                                                } ?>
                                                             </div>

                                                         </div>

                                                         <?php if (has_post_thumbnail()) {
                                                             $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                                                             $featured_image = isset($featured_image[0]) ? $featured_image[0] : ''; ?>
                                                             <div class="column column-4 column-sm-12">
                                                                 <div class="entry-thumbnail mb-sm-20">
                                                                     <a href="<?php the_permalink(); ?>">
                                                                         <span class="data-bg data-bg-big" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                                                     </a>
                                                                 </div>
                                                             </div>
                                                         <?php } ?>

                                                     <?php
                                                     endwhile;
                                                     wp_reset_postdata();
                                                 endif; ?>
                                             </div>
                                         </div>

                                         <?php
                                         if (!empty($bozu_services_pages)) {
                                             $bozu_services_add_page_args = array(
                                                 'posts_per_page' => 2,
                                                 'orderby' => 'post__in',
                                                 'post_type' => 'page',
                                                 'post__in' => $bozu_services_pages,
                                             );

                                             $bozu_services_add_page_query = new WP_Query($bozu_services_add_page_args); ?>
                                             <div class="theme-block-services-lower">
                                                 <div class="column-row">
                                                     <?php
                                                     if ($bozu_services_add_page_query->have_posts()) :
                                                         while ($bozu_services_add_page_query->have_posts()) : $bozu_services_add_page_query->the_post();
                                                             ?>
                                                             <div class="column column-6 column-sm-12">
                                                                 <div class="column-row column-row-small">
                                                                     <?php if (has_post_thumbnail()) {
                                                                         $featured_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'medium_large');
                                                                         $featured_image = isset($featured_image[0]) ? $featured_image[0] : ''; ?>
                                                                         <div class="column column-6 column-sm-12">
                                                                             <div class="entry-thumbnail mb-sm-20">
                                                                                 <a href="<?php the_permalink(); ?>">
                                                                                     <span class="data-bg data-bg-medium" data-background="<?php echo esc_url($featured_image); ?>"></span>
                                                                                 </a>
                                                                             </div>
                                                                         </div>
                                                                     <?php } ?>


                                                                     <div class="column column-6 column-sm-12">
                                                                         <div class="theme-block-heading">
                                                                             <h3 class="theme-block-title theme-block-title-medium">
                                                                                 <a href="<?php the_permalink(); ?>">
                                                                                     <?php the_title(); ?>
                                                                                 </a>
                                                                             </h3>
                                                                             <div class="post-content post-content-small">
                                                                                <?php if (has_excerpt()) {
                                                                                    the_excerpt();
                                                                                    bozu_read_more_page_render();
                                                                                } else {
                                                                                    the_excerpt();
                                                                                } ?>
                                                                             </div>
                                                                         </div>
                                                                     </div>
                                                                 </div>
                                                             </div>
                                                         <?php
                                                         endwhile;
                                                         wp_reset_postdata();
                                                     endif; ?>

                                                 </div>
                                             </div>
                                         <?php } ?>
                                     </div>
                                </div>
                         </div>

                    </div>

                </div>




        <?php }
    }

endif;


if( !function_exists( 'bozu_contact_section' ) ) :

    function bozu_contact_section(){
        $bozu_default = bozu_get_default_theme_options();
        $ed_contact_section = get_theme_mod( 'ed_contact_section', $bozu_default['ed_contact_section'] );
        $contact_section_title = get_theme_mod( 'contact_section_title', $bozu_default['contact_section_title'] );
        $contact_section_location = get_theme_mod( 'contact_section_location', $bozu_default['contact_section_location'] );
        $contact_section_email = get_theme_mod( 'contact_section_email', $bozu_default['contact_section_email'] );
        $contact_section_number = get_theme_mod( 'contact_section_number', $bozu_default['contact_section_number'] );
        $contact_form_shortcode = get_theme_mod( 'contact_form_shortcode' );
        $contact_section_bg_image = get_theme_mod( 'contact_section_bg_image');
        if ($ed_contact_section) { ?>

            <div class="theme-block theme-block-space-top theme-block-bg theme-block-contact">
                <div class="wrapper-fluid">
                    <div class="column-row column-row-center">
                        <div class="column column-1 column-sm-12">
                            <div class="theme-section-heading">
                                <h2 class="theme-section-title alt-font"><?php echo esc_html($contact_section_title); ?></h2>
                            </div>
                        </div>
                        <div class="column column-3 column-sm-12">
                            <ul class="theme-contact-list">
                                <?php if ($contact_section_location) { ?>
                                    <li class="theme-contact-list-group">
                                        <div class="theme-contact-list-title">
                                            <?php echo esc_html__('Location:', 'bozu') ?>
                                        </div>
                                        <div class="theme-contact-list-content">
                                            <?php echo esc_html($contact_section_location); ?>
                                        </div>
                                    </li>
                                <?php } ?>

                                <li class="theme-contact-list-group">
                                    <?php if (!empty($contact_section_number) || !empty($contact_section_email)) { ?>
                                        <div class="theme-contact-list-title">
                                            <?php echo esc_html__('Contact:','bozu') ?>
                                        </div>
                                    <?php } ?>
                                    <div class="theme-contact-list-content">

                                        <?php if ($contact_section_number) { ?>
                                            <div class="contact-list-content-phone">
                                                <div class="contact-list-content-icon">

                                                </div>
                                                <div class="contact-list-content-detail">
                                                    <a href="tel:<?php echo absint($contact_section_number); ?>">
                                                        <?php echo absint($contact_section_number); ?>
                                                    </a>
                                                </div>
                                            </div>
                                        <?php } ?>
                                        <?php if ($contact_section_email) { ?>
                                            <div class="contact-list-content-email">
                                                <div class="contact-list-content-icon">

                                                </div>
                                                <div class="contact-list-content-detail">
                                                    <a href="mailto:<?php echo sanitize_email($contact_section_email); ?>">
                                                        <?php echo sanitize_email($contact_section_email); ?>
                                                    </a>
                                                </div>
                                            </div>
                                        <?php } ?>
                                    </div>
                                </li>

                                <?php if( has_nav_menu('bozu-social-menu') ){ ?>
                                    <li class="theme-contact-list-group">
                                        <div class="theme-contact-list-title">
                                            <?php echo esc_html__('Follow Us On:','bozu') ?>
                                        </div>

                                        <div class="theme-social-navigation theme-contact-list-content">
                                            <?php wp_nav_menu(array(
                                                'theme_location' => 'bozu-social-menu',
                                                'link_before' => '<span class="screen-reader-text">',
                                                'link_after' => '</span>',
                                                'container' => 'div',
                                                'container_class' => 'social-menu',
                                                'depth' => 1,
                                            )); ?>
                                        </div>

                                    </li>
                                <?php } ?>
                            </ul>
                        </div>

                        <div class="column column-4 column-sm-12 mb-sm-20">
                            <?php if ($contact_section_bg_image) { ?>
                                <div class="entry-thumbnail">
                                    <img src="<?php echo esc_url($contact_section_bg_image); ?>">
                                </div>
                            <?php } ?>
                        </div>

                        <div class="column column-4 column-sm-12">
                            <div class="theme-block-heading">
                                <h3 class="theme-block-title theme-block-title-medium">
                                    <?php echo esc_html__('Send Us A Message','bozu') ?>
                                </h3>
                                <div class="post-content">
                                    <?php echo do_shortcode( $contact_form_shortcode ); ?>
                                </div>
                            </div>

                        </div>
                    </div>
                </div>
            </div>

        <?php }
    }

endif;



if( !function_exists( 'bozu_fonts_url' ) ) :

    //Google Fonts URL
    function bozu_fonts_url(){

        $font_families = array(
            'Open+Sans:ital,wght@0,300;0,400;0,500;0,600;0,700;1,300;1,400;1,500;1,600;1,700',
            'Gilda+Display',
            'Herr+Von+Muellerhoff'
        );

        $fonts_url = add_query_arg( array(
            'family' => implode( '&family=', $font_families ),
            'display' => 'swap',
        ), 'https://fonts.googleapis.com/css2' );

        return esc_url_raw($fonts_url);

    }

endif;

if( !function_exists('bozu_read_more_render') ):

    function bozu_read_more_render(){ 
        $bozu_default = bozu_get_default_theme_options();
        $ed_post_excerpt = get_theme_mod( 'ed_post_excerpt',$bozu_default['ed_post_excerpt'] );
        if( $ed_post_excerpt ){ ?>

        <div class="mp-read-more">
            <a class="mp-read-more-src" href="<?php the_permalink(); ?>"><?php esc_html_e('Read More','bozu'); ?></a>
        </div>

    <?php }
    }

endif;

if( !function_exists('bozu_read_more_page_render') ):

    function bozu_read_more_page_render(){ ?>

        <div class="mp-read-more">
            <a class="mp-read-more-src" href="<?php the_permalink(); ?>"><?php esc_html_e('Continue reading','bozu'); ?></a>
        </div>

    <?php }
endif;


if( !function_exists( 'bozu_social_menu_icon' ) ) :

    function bozu_social_menu_icon( $item_output, $item, $depth, $args ) {

        // Add Icon
        if ( isset( $args->theme_location ) &&'bozu-social-menu' === $args->theme_location ) {

            $svg = Bozu_SVG_Icons::get_theme_svg_name( $item->url );

            if ( empty( $svg ) ) {
                $svg = bozu_the_theme_svg( 'link',$return = true );
            }

            $item_output = str_replace( $args->link_after, '</span>' . $svg, $item_output );
        }

        return $item_output;
    }
    
endif;

add_filter( 'walker_nav_menu_start_el', 'bozu_social_menu_icon', 10, 4 );

if( !function_exists( 'bozu_add_sub_toggles_to_main_menu' ) ) :

    function bozu_add_sub_toggles_to_main_menu( $args, $item, $depth ) {

        // Add sub menu toggles to the Expanded Menu with toggles.
        if( isset( $args->show_toggles ) && $args->show_toggles ){

            // Wrap the menu item link contents in a div, used for positioning.
            $args->before = '<div class="submenu-wrapper">';
            $args->after  = '';

            // Add a toggle to items with children.
            if( in_array( 'menu-item-has-children', $item->classes, true ) ){

                $toggle_target_string = '.menu-item.menu-item-' . $item->ID . ' > .sub-menu';
                // Add the sub menu toggle.
                $args->after .= '<button class="toggle submenu-toggle" data-toggle-target="' . $toggle_target_string . '" data-toggle-type="slidetoggle" data-toggle-duration="250" aria-expanded="false"><span class="btn__content" tabindex="-1"><span class="screen-reader-text">' . __( 'Show sub menu', 'bozu' ) . '</span>' . bozu_the_theme_svg( 'chevron-down',$return = true ) . '</span></button>';

            }

            // Close the wrapper.
            $args->after .= '</div><!-- .submenu-wrapper -->';

            // Add sub menu icons to the primary menu without toggles.
        }elseif(isset( $args->theme_location ) && 'bozu-primary-menu' === $args->theme_location ){

            if( in_array( 'menu-item-has-children', $item->classes, true ) ){

                $args->after = '<span class="icon">'.bozu_the_theme_svg('chevron-down',true).'</span>';

            }else{

                $args->after = '';

            }
        }

        return $args;

    }

endif;

add_filter( 'nav_menu_item_args', 'bozu_add_sub_toggles_to_main_menu', 10, 3 );

if( !function_exists( 'bozu_sanitize_sidebar_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function bozu_sanitize_sidebar_option_meta( $input ){

        $metabox_options = array( 'global-sidebar','left-sidebar','right-sidebar','no-sidebar' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }
    }

endif;

if( !function_exists( 'bozu_page_lists' ) ) :

    // Page List.
    function bozu_page_lists(){

        $page_lists = array();
        $page_lists[''] = esc_html__( '-- Select Page --','bozu' );
        $pages = get_pages();
        foreach( $pages as $page ){

            $page_lists[$page->ID] = $page->post_title;

        }
        return $page_lists;
    }

endif;

if( !function_exists( 'bozu_sanitize_post_layout_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function bozu_sanitize_post_layout_option_meta( $input ){

        $metabox_options = array( 'global-layout','layout-1','layout-2' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }

    }

endif;

if( !function_exists( 'bozu_sanitize_header_overlay_option_meta' ) ) :

    // Sidebar Option Sanitize.
    function bozu_sanitize_header_overlay_option_meta( $input ){

        $metabox_options = array( 'global-layout','enable-overlay' );
        if( in_array( $input,$metabox_options ) ){

            return $input;

        }else{

            return '';

        }

    }

endif;

/**
 * Bozu SVG Icon helper functions
 *
 * @package Bozu
 * @since 1.0.0
 */
if ( ! function_exists( 'bozu_the_theme_svg' ) ):
    /**
     * Output and Get Theme SVG.
     * Output and get the SVG markup for an icon in the Bozu_SVG_Icons class.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function bozu_the_theme_svg( $svg_name, $return = false ) {

        if( $return ){

            return bozu_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in bozu_get_theme_svg();.

        }else{

            echo bozu_get_theme_svg( $svg_name ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in bozu_get_theme_svg();.
            
        }
    }

endif;

if ( ! function_exists( 'bozu_get_theme_svg' ) ):

    /**
     * Get information about the SVG icon.
     *
     * @param string $svg_name The name of the icon.
     * @param string $group The group the icon belongs to.
     * @param string $color Color code.
     */
    function bozu_get_theme_svg( $svg_name ) {

        // Make sure that only our allowed tags and attributes are included.
        $svg = wp_kses(
            Bozu_SVG_Icons::get_svg( $svg_name ),
            array(
                'svg'     => array(
                    'class'       => true,
                    'xmlns'       => true,
                    'width'       => true,
                    'height'      => true,
                    'viewbox'     => true,
                    'aria-hidden' => true,
                    'role'        => true,
                    'focusable'   => true,
                ),
                'path'    => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'd'         => true,
                    'transform' => true,
                ),
                'polygon' => array(
                    'fill'      => true,
                    'fill-rule' => true,
                    'points'    => true,
                    'transform' => true,
                    'focusable' => true,
                ),
            )
        );
        if ( ! $svg ) {
            return false;
        }
        return $svg;

    }

endif;


if( !function_exists( 'bozu_post_category_list' ) ) :

    // Post Category List.
    function bozu_post_category_list( $select_cat = true ){

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $post_cat_cat_array = array();
        if( $select_cat ){

            $post_cat_cat_array[''] = esc_html__( '-- Select Category --','bozu' );

        }

        foreach ( $post_cat_lists as $post_cat_list ) {

            $post_cat_cat_array[$post_cat_list->slug] = $post_cat_list->name;

        }

        return $post_cat_cat_array;
    }

endif;

if( !function_exists('bozu_sanitize_meta_pagination') ):

    /** Sanitize Enable Disable Checkbox **/
    function bozu_sanitize_meta_pagination( $input ) {

        $valid_keys = array('global-layout','no-navigation','norma-navigation','ajax-next-post-load');
        if ( in_array( $input , $valid_keys ) ) {
            return $input;
        }
        return '';

    }

endif;

if( !function_exists('bozu_disable_post_views') ):

    /** Disable Post Views **/
    function bozu_disable_post_views() {

        add_filter('booster_extension_filter_views_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('bozu_disable_post_read_time') ):

    /** Disable Read Time **/
    function bozu_disable_post_read_time() {

        add_filter('booster_extension_filter_readtime_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('bozu_disable_post_like_dislike') ):

    /** Disable Like Dislike **/
    function bozu_disable_post_like_dislike() {

        add_filter('booster_extension_filter_like_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('bozu_disable_post_author_box') ):

    /** Disable Author Box **/
    function bozu_disable_post_author_box() {

        add_filter('booster_extension_filter_ab_ed', function ( ) {
            return false;
        });

    }

endif;


add_filter('booster_extension_filter_ss_ed', function ( ) {
    return false;
});

if( !function_exists('bozu_disable_post_reaction') ):

    /** Disable Reaction **/
    function bozu_disable_post_reaction() {

        add_filter('booster_extension_filter_reaction_ed', function ( ) {
            return false;
        });

    }

endif;

if( !function_exists('bozu_post_floating_nav') ):

    function bozu_post_floating_nav(){

        $bozu_default = bozu_get_default_theme_options();
        $ed_floating_next_previous_nav = get_theme_mod( 'ed_floating_next_previous_nav',$bozu_default['ed_floating_next_previous_nav'] );

        if( 'post' === get_post_type() && $ed_floating_next_previous_nav ){

            $next_post = get_next_post();
            $prev_post = get_previous_post();

            if( isset( $prev_post->ID ) ){

                $prev_link = get_permalink( $prev_post->ID );?>

                <div class="floating-post-navigation floating-navigation-prev">
                    <?php if( get_the_post_thumbnail( $prev_post->ID,'medium_large' ) ){ ?>
                            <?php echo wp_kses_post( get_the_post_thumbnail( $prev_post->ID,'medium_large' ) ); ?>
                    <?php } ?>
                    <a href="<?php echo esc_url( $prev_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Previous post', 'bozu'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $prev_post->ID ) ); ?></span>
                    </a>
                </div>

            <?php }

            if( isset( $next_post->ID ) ){

                $next_link = get_permalink( $next_post->ID );?>

                <div class="floating-post-navigation floating-navigation-next">
                    <?php if( get_the_post_thumbnail( $next_post->ID,'medium_large' ) ){ ?>
                        <?php echo wp_kses_post( get_the_post_thumbnail( $next_post->ID,'medium_large' ) ); ?>
                    <?php } ?>
                    <a href="<?php echo esc_url( $next_link ); ?>">
                        <span class="floating-navigation-label"><?php echo esc_html__('Next post', 'bozu'); ?></span>
                        <span class="floating-navigation-title"><?php echo esc_html( get_the_title( $next_post->ID ) ); ?></span>
                    </a>
                </div>

            <?php
            }

        }

    }

endif;

add_action( 'bozu_navigation_action','bozu_post_floating_nav',10 );

if( !function_exists('bozu_single_post_navigation') ):

    function bozu_single_post_navigation(){

        $bozu_default = bozu_get_default_theme_options();
        $twp_navigation_type = esc_attr( get_post_meta( get_the_ID(), 'twp_disable_ajax_load_next_post', true ) );
        global $post;
        if( $twp_navigation_type == '' || $twp_navigation_type == 'global-layout' ){
            $twp_navigation_type = get_theme_mod('twp_navigation_type', $bozu_default['twp_navigation_type']);
        }


        if( $twp_navigation_type != 'no-navigation' && 'post' === get_post_type() ){

            if( $twp_navigation_type == 'norma-navigation' ){ ?>

                <div class="theme-block navigation-wrapper">
                    <?php
                    // Previous/next post navigation.
                    the_post_navigation(array(
                        'prev_text' => '<span class="arrow" aria-hidden="true">' . bozu_the_theme_svg('arrow-left',$return = true ) . '</span><span class="screen-reader-text">' . __('Previous post:', 'bozu') . '</span><h4 class="entry-title entry-title-medium">%title</h4>',
                        'next_text' => '<span class="arrow" aria-hidden="true">' . bozu_the_theme_svg('arrow-right',$return = true ) . '</span><span class="screen-reader-text">' . __('Next post:', 'bozu') . '</span><h4 class="entry-title entry-title-medium">%title</h4>',
                    )); ?>
                </div>
                <?php

            }else{

                $next_post = get_next_post();
                if( isset( $next_post->ID ) ){

                    $next_post_id = $next_post->ID;
                    echo '<div loop-count="1" next-post="' . absint( $next_post_id ) . '" class="twp-single-infinity"></div>';

                }
            }

        }

    }

endif;

add_action( 'bozu_navigation_action','bozu_single_post_navigation',30 );

if ( ! function_exists( 'bozu_header_toggle_search' ) ):

    /**
     * Header Search
     **/
    function bozu_header_toggle_search() {

        $bozu_default = bozu_get_default_theme_options();
        $ed_header_search = get_theme_mod( 'ed_header_search', $bozu_default['ed_header_search'] );
        $ed_header_search_top_category = get_theme_mod( 'ed_header_search_top_category', $bozu_default['ed_header_search_top_category'] );
        $ed_header_search_recent_posts = absint( get_theme_mod( 'ed_header_search_recent_posts',$bozu_default['ed_header_search_recent_posts'] ) );
        
        if( $ed_header_search ){ ?>

            <div class="header-searchbar">
                <div class="header-searchbar-inner">
                    <div class="wrapper">

                        <div class="header-searchbar-area">

                            <a href="javascript:void(0)" class="skip-link-search-start"></a>
                            
                            <?php get_search_form(); ?>

                        </div>

                        <?php if( $ed_header_search_recent_posts || $ed_header_search_top_category ){ ?>

                            <div class="search-content-area">
                                  
                                <?php if( $ed_header_search_recent_posts ){ ?>

                                    <div class="search-recent-posts">
                                        <?php bozu_recent_posts_search(); ?>
                                    </div>

                                <?php } ?>

                                <?php if( $ed_header_search_top_category ){ ?>

                                    <div class="search-popular-categories">
                                        <?php bozu_header_search_top_cat_content(); ?>
                                    </div>

                                <?php } ?>

                            </div>

                        <?php } ?>

                        <button type="button" id="search-closer" class="exit-search">
                            <?php bozu_the_theme_svg('cross'); ?>
                        </button>

                        <a href="javascript:void(0)" class="skip-link-search-end"></a>

                    </div>
                </div>
            </div>

        <?php
        }

    }

endif;

if( !function_exists('bozu_recent_posts_search') ):

    // Single Posts Related Posts.
    function bozu_recent_posts_search(){

        $bozu_default = bozu_get_default_theme_options();
        $related_posts_query = new WP_Query( array('post_type' => 'post', 'posts_per_page' => 5,'post__not_in' => get_option("sticky_posts") ) );

        if( $related_posts_query->have_posts() ): ?>

            <div class="related-search-posts">

                <div class="theme-block-heading">
                    <?php
                    $recent_post_title_search = esc_html( get_theme_mod( 'recent_post_title_search',$bozu_default['recent_post_title_search'] ) );

                    if( $recent_post_title_search ){ ?>
                        <h2 class="theme-block-title">

                            <?php echo esc_html( $recent_post_title_search ); ?>

                        </h2>
                    <?php } ?>
                </div>

                <div class="theme-list-group recent-list-group">

                    <?php
                    while( $related_posts_query->have_posts() ):
                        $related_posts_query->the_post(); ?>

                        <div class="search-recent-article-list">
                            <header class="entry-header">
                                <h3 class="entry-title entry-title-medium">
                                    <a href="<?php the_permalink(); ?>" rel="bookmark">
                                        <?php the_title(); ?>
                                    </a>
                                </h3>
                            </header>
                        </div>

                    <?php 
                    endwhile; ?>

                </div>

            </div>

            <?php
            wp_reset_postdata();

        endif;

    }

endif;

if( !function_exists('bozu_header_search_top_cat_content') ):

    function bozu_header_search_top_cat_content(){

        $top_category = 3;

        $post_cat_lists = get_categories(
            array(
                'hide_empty' => '0',
                'exclude' => '1',
            )
        );

        $slug_counts = array();

        foreach( $post_cat_lists as $post_cat_list ){

            if( $post_cat_list->count >= 1 ){

                $slug_counts[] = array( 
                    'count'         => $post_cat_list->count,
                    'slug'          => $post_cat_list->slug,
                    'name'          => $post_cat_list->name,
                    'cat_ID'        => $post_cat_list->cat_ID,
                    'description'   => $post_cat_list->category_description, 
                );

            }

        }

        if( $slug_counts ){?>

            <div class="popular-search-categories">
                
                <div class="theme-block-heading">
                    <?php
                    $bozu_default = bozu_get_default_theme_options();
                    $top_category_title_search = esc_html( get_theme_mod( 'top_category_title_search',$bozu_default['top_category_title_search'] ) );

                    if( $top_category_title_search ){ ?>
                        <h2 class="theme-block-title">

                            <?php echo esc_html( $top_category_title_search ); ?>

                        </h2>
                    <?php } ?>
                </div>

                <?php
                arsort( $slug_counts ); ?>

                <div class="theme-list-group categories-list-group">
                    <div class="column-row">

                        <?php
                        $i = 1;
                        foreach( $slug_counts as $key => $slug_count ){

                            if( $i > $top_category){ break; }
                            
                            $cat_link           = get_category_link( $slug_count['cat_ID'] );
                            $cat_name           = $slug_count['name'];
                            $twp_term_image = get_term_meta( $slug_count['cat_ID'], 'twp-term-featured-image', true ); ?>

                            <div class="column column-4 column-sm-12">
                                <article id="post-<?php the_ID(); ?>" <?php post_class('theme-grid-article'); ?>>
                                        <div class="entry-wrapper">
                                            <?php if ($twp_term_image) { ?>
                                                <div class="entry-thumbnail">
                                                    <a href="<?php echo esc_url($cat_link); ?>" class="data-bg data-bg-medium" data-background="<?php echo esc_url($twp_term_image); ?>"></a>
                                                </div>
                                            <?php } ?>

                                            <div class="post-content">
                                                <header class="entry-header">
                                                    <h3 class="entry-title">
                                                        <a href="<?php echo esc_url($cat_link); ?>">
                                                            <?php echo esc_html($cat_name); ?>
                                                        </a>
                                                    </h3>
                                                </header>
                                            </div>
                                        </div>
                                </article>
                            </div>

                            <?php
                            $i++;

                        } ?>

                    </div>
                </div>

            </div>
        <?php
        }

    }

endif;

add_action( 'bozu_before_footer_content_action','bozu_header_toggle_search',10 );

if( !function_exists('bozu_content_offcanvas') ):

    // Offcanvas Contents
    function bozu_content_offcanvas(){ ?>

        <div id="offcanvas-menu">
            <div class="offcanvas-wraper">

                <div class="close-offcanvas-menu">
                    <div class="offcanvas-close">

                        <a href="javascript:void(0)" class="skip-link-menu-start"></a>

                        <button type="button" class="button-offcanvas-close">
                            <?php bozu_the_theme_svg('close'); ?>
                        </button>

                    </div>
                </div>

                <div id="primary-nav-offcanvas" class="offcanvas-item offcanvas-main-navigation">
                    <nav class="primary-menu-wrapper" aria-label="<?php esc_attr_e('Horizontal', 'bozu'); ?>" role="navigation">
                        <ul class="primary-menu theme-menu">

                            <?php
                            if( has_nav_menu('bozu-primary-menu') ){

                                wp_nav_menu(
                                    array(
                                        'container' => '',
                                        'items_wrap' => '%3$s',
                                        'theme_location' => 'bozu-primary-menu',
                                        'show_toggles' => true,
                                    )
                                );

                            }else{
                                
                                wp_list_pages(
                                    array(
                                        'match_menu_classes' => true,
                                        'show_sub_menu_icons' => false,
                                        'title_li' => false,
                                        'show_toggles' => true,
                                        'walker' => new Bozu_Walker_Page(),
                                    )
                                );
                            } ?>

                        </ul>
                    </nav><!-- .primary-menu-wrapper -->
                </div>

                <?php if( has_nav_menu('bozu-social-menu') ){ ?>

                    <div id="social-nav-offcanvas" class="offcanvas-item theme-social-navigation">

                        <?php
                        wp_nav_menu(array(
                            'theme_location' => 'bozu-social-menu',
                            'link_before' => '<span class="screen-reader-text">',
                            'link_after' => '</span>',
                            'container' => 'div',
                            'container_class' => 'social-menu',
                            'depth' => 1,
                        )); ?>

                    </div>

                <?php } ?>

                <a href="javascript:void(0)" class="skip-link-menu-end"></a>

            </div>
        </div>

    <?php
    }

endif;

add_action( 'bozu_before_footer_content_action','bozu_content_offcanvas',30 );

if( !function_exists('bozu_footer_content_widget') ):

    function bozu_footer_content_widget(){

        $bozu_default = bozu_get_default_theme_options();
        if( is_active_sidebar('bozu-footer-widget-0') || 
            is_active_sidebar('bozu-footer-widget-1') || 
            is_active_sidebar('bozu-footer-widget-2') ):

            $x = 1;
            $footer_sidebar = 0;
            do {
                if ($x == 3 && is_active_sidebar('bozu-footer-widget-2')) {
                    $footer_sidebar++;
                }
                if ($x == 2 && is_active_sidebar('bozu-footer-widget-1')) {
                    $footer_sidebar++;
                }
                if ($x == 1 && is_active_sidebar('bozu-footer-widget-0')) {
                    $footer_sidebar++;
                }
                $x++;
            } while ($x <= 3);
            if ($footer_sidebar == 1) {
                $footer_sidebar_class = 12;
            } elseif ($footer_sidebar == 2) {
                $footer_sidebar_class = 6;
            } else {
                $footer_sidebar_class = 4;
            }
            $footer_column_layout = absint(get_theme_mod('footer_column_layout', $bozu_default['footer_column_layout'])); ?>

            <div class="footer-widgetarea">
                <div class="wrapper">
                    <div class="column-row">

                        <?php if (is_active_sidebar('bozu-footer-widget-0')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('bozu-footer-widget-0'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('bozu-footer-widget-1')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('bozu-footer-widget-1'); ?>
                            </div>
                        <?php endif; ?>

                        <?php if (is_active_sidebar('bozu-footer-widget-2')): ?>
                            <div class="column <?php echo 'column-' . absint($footer_sidebar_class); ?> column-sm-12">
                                <?php dynamic_sidebar('bozu-footer-widget-2'); ?>
                            </div>
                        <?php endif; ?>

                    </div>
                </div>
            </div>

        <?php
        endif;

    }

endif;

add_action( 'bozu_footer_widget_area_content_action','bozu_footer_content_widget',10 );


if (!function_exists('bozu_footer_logo_section')):

    function bozu_footer_logo_section()
    {
        $footer_logo_upload = esc_url(get_theme_mod('footer_logo_upload'));
        if (!empty( $footer_logo_upload)) {
            ?>
            <div class="theme-footer-logo">
                <a href="<?php echo esc_url(get_site_url()); ?>">
                    <img src="<?php echo esc_url($footer_logo_upload); ?>">
                </a>
            </div>
            <?php
        }
    }

endif;

add_action( 'bozu_footer_content_action','bozu_footer_logo_section',12 );



if (!function_exists('bozu_footer_social_nav')):

    function bozu_footer_social_nav()
    {
        $bozu_default = bozu_get_default_theme_options();
        $ed_footer_social_nav = get_theme_mod('ed_footer_social_nav', $bozu_default['ed_footer_social_nav']);

        if (has_nav_menu('bozu-social-menu') && ($ed_footer_social_nav)) { ?>
            <div id="footer-social-nav" class="theme-social-navigation footer-social-navigation">
                <div class="theme-block-heading">
                    <h2 class="theme-block-title theme-block-title-xlarge alt-font">
                        <?php esc_html_e('follow us', 'bozu'); ?>
                    </h2>
                </div>
                <?php
                wp_nav_menu(array(
                    'theme_location' => 'bozu-social-menu',
                    'link_before' => '<span class="screen-reader-text">',
                    'link_after' => '</span>',
                    'container' => 'div',
                    'container_class' => 'social-menu',
                    'depth' => 1,
                )); ?>
            </div>
        <?php } ?>
        <?php
    }

endif;

add_action( 'bozu_footer_content_action','bozu_footer_social_nav',15 );



if( !function_exists('bozu_footer_content_info') ):

    /**
     * Footer Copyright Area
    **/
    function bozu_footer_content_info(){

        $bozu_default = bozu_get_default_theme_options(); ?>

        <div class="site-info">
            <div class="wrapper">
                <div class="column-row">
                    <div class="column column-12">
                        <div class="footer-credits">

                            <div class="footer-copyright">

                                <?php
                                $ed_footer_copyright = wp_kses_post(get_theme_mod('ed_footer_copyright', $bozu_default['ed_footer_copyright']));
                                $footer_copyright_text = wp_kses_post(get_theme_mod('footer_copyright_text', $bozu_default['footer_copyright_text']));

                                echo esc_html__('Copyright ', 'bozu') . '&copy ' . absint(date('Y')) . ' <a href="' . esc_url(home_url('/')) . '" title="' . esc_attr(get_bloginfo('name', 'display')) . '" ><span>' . esc_html(get_bloginfo('name', 'display')) . '. </span></a> ' . esc_html($footer_copyright_text);

                                if ($ed_footer_copyright) {

                                    echo '<br>';
                                    echo esc_html__('Theme: ', 'bozu') . 'Bozu ' . esc_html__('By ', 'bozu') . '<a href="' . esc_url('https://www.themeinwp.com/theme/bozu') . '"  title="' . esc_attr__('Themeinwp', 'bozu') . '" target="_blank" rel="author"><span>' . esc_html__('Themeinwp. ', 'bozu') . '</span></a>';

                                    echo esc_html__('Powered by ', 'bozu') . '<a href="' . esc_url('https://wordpress.org') . '" title="' . esc_attr__('WordPress', 'bozu') . '" target="_blank"><span>' . esc_html__('WordPress.', 'bozu') . '</span></a>';

                                } ?>

                            </div>
                        </div>
                    </div>

                </div>
            </div>
        </div>

    <?php
    }

endif;

add_action( 'bozu_footer_content_action','bozu_footer_content_info',20 );


if( !function_exists('bozu_footer_go_to_top') ):

    // Scroll to Top render content
    function bozu_footer_go_to_top(){ ?>

        <button type="button" class="scroll-up">
                <span class="scroll-ip-icon">
                            <?php bozu_the_theme_svg('arrow-up-alt'); ?>
                </span>
        </button>
    
    <?php
    }

endif;

add_action( 'bozu_footer_content_action','bozu_footer_go_to_top',30 );

if( !function_exists('bozu_color_schema_color') ):

    function bozu_color_schema_color( $current_color ){

        $bozu_default = bozu_get_default_theme_options();

        $colors_schema = array(

            'default' => array(

                'background_color' => '#ffffff',
                'bozu_primary_color' => $bozu_default['bozu_primary_color'],
                'bozu_secondary_color' => $bozu_default['bozu_secondary_color'],
                'bozu_general_color' => $bozu_default['bozu_general_color'],

            ),

            'dark' => array(

                'background_color' => '#222222',
                'bozu_primary_color' => $bozu_default['bozu_primary_color_dark'],
                'bozu_secondary_color' => $bozu_default['bozu_secondary_color_dark'],
                'bozu_general_color' => $bozu_default['bozu_general_color_dark'],

            ),

            'fancy' => array(

                'background_color' => '#faf7f2',
                'bozu_primary_color' => $bozu_default['bozu_primary_color_fancy'],
                'bozu_secondary_color' => $bozu_default['bozu_secondary_color_fancy'],
                'bozu_general_color' => $bozu_default['bozu_general_color_fancy'],

            ),

        );

        if( isset( $colors_schema[$current_color] ) ){
            
            return $colors_schema[$current_color];

        }

        return;

    }

endif;



if ( ! function_exists( 'bozu_color_schema_color_action' ) ) :
    
    function bozu_color_schema_color_action() {

        if( isset( $_POST['currentColor'] ) && sanitize_text_field( wp_unslash( $_POST['currentColor'] ) ) ){
         
            $current_color = sanitize_text_field( wp_unslash( $_POST['currentColor'] ) );

            $color_schemes = bozu_color_schema_color( $current_color );

            if ( $color_schemes ) {
                echo json_encode( $color_schemes );
            }
        }
    
        wp_die();

    }

endif;

add_action( 'wp_ajax_nopriv_bozu_color_schema_color', 'bozu_color_schema_color_action' );
add_action( 'wp_ajax_bozu_color_schema_color', 'bozu_color_schema_color_action' );

if( ! function_exists( 'bozu_iframe_escape' ) ):
    
    /** Escape Iframe **/
    function bozu_iframe_escape( $input ){

        $all_tags = array(
            'iframe'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'frameborder'=>array(),
                'allow'=>array(),
                'allowfullscreen'=>array(),
            ),
            'video'=>array(
                'width'=>array(),
                'height'=>array(),
                'src'=>array(),
                'style'=>array(),
                'controls'=>array(),
            )
        );

        return wp_kses($input,$all_tags);
        
    }

endif;

if( class_exists( 'Booster_Extension_Class' ) ){

    add_filter('booster_extemsion_content_after_filter','bozu_after_content_pagination');

}

if( !function_exists('bozu_after_content_pagination') ):

    function bozu_after_content_pagination($after_content){

        $pagination_single = wp_link_pages( array(
                    'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'bozu' ),
                    'after'  => '</div>',
                    'echo' => false
                ) );

        $after_content =  $pagination_single.$after_content;

        return $after_content;

    }

endif;

if( !function_exists('bozu_excerpt_content') ):

    function bozu_excerpt_content(){ 

        $bozu_default = bozu_get_default_theme_options();
        $ed_post_excerpt = get_theme_mod( 'ed_post_excerpt',$bozu_default['ed_post_excerpt'] );

        if( $ed_post_excerpt ){ ?>
                    
            <div class="entry-content">

                <?php
                if( has_excerpt() ){

                    the_excerpt();

                }else{

                    echo esc_html( wp_trim_words( get_the_content(), 25, '...' ) );

                } ?>

            </div>

        <?php }
    }

endif;


if( !function_exists('bozu_footer_related_posts') ):

    // Footer Posts Related Posts.
    function bozu_footer_related_posts(){
        
        $bozu_default = bozu_get_default_theme_options();
        $enable_footer_related_post = esc_html(get_theme_mod('enable_footer_related_post', $bozu_default['enable_footer_related_post']));
        if ($enable_footer_related_post) {
            $footer_related_posts_query = new WP_Query(
                    array(
                    'post_type' => 'post',
                    'posts_per_page' => absint( get_theme_mod( 'number_of_footer_related_post')),
                    'cat' => esc_attr(get_theme_mod( 'select_category_for_related_post')),
                    )
            );

            if( $footer_related_posts_query->have_posts() ): ?>
                <div class="theme-block theme-block-bg-2 theme-block-recommended">
                    <div class="wrapper-fluid">
                        <div class="column-row">
                            <div class="column column-3 column-sm-12">
                                <div class="theme-block-heading">
                                <?php
                                $footer_recent_post_title = esc_html(get_theme_mod('footer_related_post_title', $bozu_default['footer_related_post_title']));
                                $footer_related_post_sub_title = esc_html(get_theme_mod('footer_related_post_sub_title', $bozu_default['footer_related_post_sub_title']));

                                if ($footer_recent_post_title) { ?>

                                    <h2 class="theme-block-title theme-block-title-large">

                                        <?php echo esc_html($footer_recent_post_title); ?>

                                    </h2>

                                    <?php } ?>
                                    <?php if ($footer_related_post_sub_title) {
                                       echo esc_html($footer_related_post_sub_title);
                                    }?>
                                </div>
                            </div>
                            <div class="column column-9 column-sm-12">
                                <div class="theme-recommended-slider slick-space">
                                    <?php
                                    while ($footer_related_posts_query->have_posts()):
                                        $footer_related_posts_query->the_post(); ?>
                                        <article <?php post_class('recommended-slides'); ?>>
                                            <div class="entry-wrapper">

                                                <?php if( has_post_thumbnail() ){
                                                    $featured_image = wp_get_attachment_image_src( get_post_thumbnail_id(),'medium_large' );
                                                    $featured_image = isset( $featured_image[0] ) ? $featured_image[0] : ''; ?>

                                                    <div class="entry-thumbnail">
                                                        <a href="<?php the_permalink(); ?>">
                                                            <span class="data-bg data-bg-medium-large" data-background="<?php echo esc_url( $featured_image ); ?>"></span>
                                                        </a>
                                                    </div>

                                                <?php }?>

                                                <div class="post-content">
                                                    <div class="entry-meta">
                                                        <?php bozu_entry_footer($cats = true, $tags = false, $edits = false); ?>
                                                    </div>

                                                    <header class="entry-header">
                                                        <h3 class="entry-title entry-title-medium">
                                                            <a href="<?php the_permalink(); ?>">
                                                                <?php the_title(); ?>
                                                            </a>
                                                        </h3>
                                                    </header>

                                                    <div class="entry-meta">

                                                        <?php
                                                        bozu_posted_by();
                                                        bozu_posted_on();
                                                        ?>

                                                    </div>

                                                </div>
                                            </div>
                                        </article>
                                    <?php
                                    endwhile;
                                    wp_reset_postdata();
                                    ?>
                                </div>
                                <?php

                                $footer_recent_post_button_text = esc_html(get_theme_mod('footer_related_post_button', $bozu_default['footer_related_post_button']));
                                $footer_recent_post_button_url = esc_html(get_theme_mod('footer_related_post_button_url', $bozu_default['footer_related_post_button_url']));

                                if ($footer_recent_post_button_text) { ?>
                                    <div class="theme-block-link">
                                        <a href="<?php echo esc_url($footer_recent_post_button_url); ?>" class="theme-button-hashed">
                                            <?php echo esc_html($footer_recent_post_button_text); ?>
                                        </a>
                                    </div>
                                <?php } ?>
                            </div>
                        </div>
                    </div>
                </div>
            <?php endif;
        }

    }

endif;



function bozu_excerpt_more( $link ) {
    if ( is_admin() ) {
        return $link;
    }

    $link = sprintf(
        '<div class="theme-link-more"><a href="%1$s" class="theme-more-link">%2$s '.bozu_the_theme_svg('arrow-right',true).'</a></div>',
        esc_url( get_permalink( get_the_ID() ) ),
        /* translators: %s: Post title. */
        sprintf( __( 'Continue reading<span class="screen-reader-text"> "%s"</span>', 'bozu' ), get_the_title( get_the_ID() ) )
    );
    return $link;
}
add_filter( 'excerpt_more', 'bozu_excerpt_more' );

/**
 * Print the first instance of a block in the content, and then break away.
 *
 * @since Bozu 1.0.5
 *
 * @param string      $block_name The full block type name, or a partial match.
 *                                Example: `core/image`, `core-embed/*`.
 * @param string|null $content    The content to search in. Use null for get_the_content().
 * @param int         $instances  How many instances of the block will be printed (max). Default  1.
 * @return bool Returns true if a block was located & printed, otherwise false.
 */
function bozu_print_first_instance_of_block( $block_name, $content = null, $instances = 1 ) {
    $instances_count = 0;
    $blocks_content  = '';

    if ( ! $content ) {
        $content = get_the_content();
    }

    // Parse blocks in the content.
    $blocks = parse_blocks( $content );

    // Loop blocks.
    foreach ( $blocks as $block ) {

        // Sanity check.
        if ( ! isset( $block['blockName'] ) ) {
            continue;
        }

        // Check if this the block matches the $block_name.
        $is_matching_block = false;

        // If the block ends with *, try to match the first portion.
        if ( '*' === $block_name[-1] ) {
            $is_matching_block = 0 === strpos( $block['blockName'], rtrim( $block_name, '*' ) );
        } else {
            $is_matching_block = $block_name === $block['blockName'];
        }

        if ( $is_matching_block ) {
            // Increment count.
            $instances_count++;

            // Add the block HTML.
            $blocks_content .= render_block( $block );

            // Break the loop if the $instances count was reached.
            if ( $instances_count >= $instances ) {
                break;
            }
        }
    }

    if ( $blocks_content ) {
        /** This filter is documented in wp-includes/post-template.php */
        echo apply_filters( 'the_content', $blocks_content ); // phpcs:ignore WordPress.Security.EscapeOutput
        return true;
    }

    return false;
}