<?php
/**
 * Default Values.
 *
 * @package Bozu
 */

if ( ! function_exists( 'bozu_get_default_theme_options' ) ) :

    /**
     * Get default theme options
     *
     * @since 1.0.0
     *
     * @return array Default theme options.
     */
    function bozu_get_default_theme_options() {

        $bozu_defaults = array();
        $bozu_category_colors = array(
            array(
                'category' => '1',
                'category_color' => '#0027ff',
            ),
        );

        $bozu_category_colors = json_encode($bozu_category_colors);
        $bozu_defaults['bozu_category_colors'] = $bozu_category_colors;

        // header banner
        $bozu_defaults['logo_width_range']                       = 500;
        $bozu_defaults['ed_header_banner']                       = 1;
        $bozu_defaults['ed_header_banner_overlay']               = 0;
        $bozu_defaults['header_banner_title']                    = esc_html__( 'Hello World', 'bozu' );
        $bozu_defaults['header_banner_sub_title']                = esc_html__( 'This is sub-title', 'bozu' );
        $bozu_defaults['header_banner_description']              = '';
        $bozu_defaults['header_banner_button_label']             = esc_html__( 'Get Started', 'bozu' );
        $bozu_defaults['header_banner_button_link']              = '';
        $bozu_defaults['ed_open_link_new_tab']                   = 1;
        $bozu_defaults['bozu_header_text_color']         = '#000000';

        $bozu_defaults['ed_top_bar_date']                   = 1;
        $bozu_defaults['top_date_format']                   = 'l, F jS, Y ';
        $bozu_defaults['ed_top_bar_clock']                   = 1;

        // homepage cta
        $bozu_defaults['ed_cta_section']                        = 0;
        $bozu_defaults['ed_cta_image_overlay']                  = 0;
        $bozu_defaults['ed_cta_post_excerpt']                  = 0;
        $bozu_defaults['cta_link_tab']                          = 0;
        $bozu_defaults['homepage_cta_button_text']              =  esc_html__( 'View More', 'bozu' );
        $bozu_defaults['homepage_cta_button_text_url']          = '';
        $bozu_defaults['homepage_cta_text_color']         = '#000000';


        // homepage about
        $bozu_defaults['ed_about_section']                      = 1;
        $bozu_defaults['about_section_title']                   =  esc_html__( 'About Us', 'bozu' );

        // homepage slider
        $bozu_defaults['ed_slider_section']                     = 0;
        $bozu_defaults['number_of_slider']                      = 2;
        $bozu_defaults['ed_slider_overlay']                = 1;
        $bozu_defaults['ed_slider_post_excerpt']                = 1;
        $bozu_defaults['ed_slider_control_dot']                = 1;
        $bozu_defaults['bozu_slider_text_color']                = '#000';

        // homepage category
        $bozu_defaults['ed_category_section']                   = 0;
        $bozu_defaults['category_title_text_color']             = '#000000';
        $bozu_defaults['ed_category_image_overlay']             = 0;
        $bozu_defaults['ed_category_description']               = 0;

        // homepage service
        $bozu_defaults['ed_services_section']                   = 0;
        $bozu_defaults['services_section_title']             = esc_html__( 'Our Services', 'bozu' );
        
        // homepage testimonial
        $bozu_defaults['ed_testimonial_section']                   = 0;
        $bozu_defaults['number_of_testimonial']                    = 3;
        $bozu_defaults['testimonial_section_title']                = esc_html__( 'Customer Testimonials', 'bozu' );
        $bozu_defaults['bozu_testimonial_bg_color']                = '#fff';
        

        // homepage contact 
        $bozu_defaults['ed_contact_section']                       = 0;
        $bozu_defaults['contact_section_title']                    = esc_html__( 'Contact US', 'bozu' );
        $bozu_defaults['contact_section_location']                 = '';
        $bozu_defaults['contact_section_email']                    = '';
        $bozu_defaults['contact_section_number']                   = '';

        // Options.
        $bozu_defaults['bozu_pagination_layout']                    = 'numeric';
        $bozu_defaults['footer_column_layout']                       = 3;
        $bozu_defaults['footer_copyright_text']                      = esc_html__( 'All rights reserved.', 'bozu' );
        $bozu_defaults['ed_header_search']                           = 1;
        $bozu_defaults['ed_image_content_inverse']                   = 0;
        $bozu_defaults['bozu_single_post_layout']                    = 'layout-1';
        $bozu_defaults['ed_related_post']                            = 1;
        $bozu_defaults['related_post_title']                         = esc_html__('Related Post','bozu');
        $bozu_defaults['twp_navigation_type']                        = 'norma-navigation';
        $bozu_defaults['ed_post_author']                             = 1;
        $bozu_defaults['ed_post_date']                               = 1;
        $bozu_defaults['ed_post_category']                           = 1;
        $bozu_defaults['ed_post_tags']                               = 1;
        $bozu_defaults['ed_floating_next_previous_nav']               = 1;
        $bozu_defaults['ed_footer_copyright']                        = 1;
        $bozu_defaults['ed_footer_social_nav']                        = 1;

        // Default Color
        $bozu_defaults['background_color']                      = 'ffffff';
        $bozu_defaults['bozu_primary_color']            = '#000000';
        $bozu_defaults['bozu_secondary_color']          = '#0027ff';
        $bozu_defaults['bozu_general_color']            = '#000000';

        // Simple Color
        $bozu_defaults['bozu_primary_color_dark']          = '#007CED';
        $bozu_defaults['bozu_secondary_color_dark']        = '#fb7268';
        $bozu_defaults['bozu_general_color_dark']        = '#ffffff';

        // Fancy Color
        $bozu_defaults['bozu_primary_color_fancy']          = '#017eff';
        $bozu_defaults['bozu_secondary_color_fancy']        = '#fc9285';
        $bozu_defaults['bozu_general_color_fancy']          = '#455d58';

        $bozu_defaults['ed_open_link_new_tab']                      = 0;
        $bozu_defaults['bozu_color_schema']                 = 'default';
        $bozu_defaults['ed_desktop_menu']                           = 1;
        $bozu_defaults['ed_post_excerpt']                           = 0;
        $bozu_defaults['recent_post_title_search']                  = esc_html__('Recent Post','bozu');
        $bozu_defaults['top_category_title_search']                 = esc_html__('Top Category','bozu');
        $bozu_defaults['ed_header_search_recent_posts']             = 1;
        $bozu_defaults['ed_header_search_top_category']             = 1;
        
        // footer related post
        $bozu_defaults['enable_footer_related_post']             = 0;
        $bozu_defaults['footer_related_post_title']              = esc_html__('You May Like','bozu');
        $bozu_defaults['footer_related_post_sub_title']          = esc_html__('This is sub-title','bozu');
        $bozu_defaults['number_of_footer_related_post']          = 8;
        $bozu_defaults['select_category_for_related_post']       = 0;
        $bozu_defaults['footer_related_post_button']             = esc_html__('View Blog','bozu');
        $bozu_defaults['footer_related_post_button_url']         = '';

        $bozu_defaults['home_section_arrange_vals_1']                             =  'homepage_about_Section,homepage_slider_Section,homepage_category_Section,homepage_services_Section,homepage_cta_Section,homepage_testimonial_Section,static_front_page,homepage_footer_recomend_section,homepage_contact_Section';

        // Pass through filter.
        $bozu_defaults = apply_filters( 'bozu_filter_default_theme_options', $bozu_defaults );

        return $bozu_defaults;

    }

endif;
